@@ -1,6 +1,6 @@
 import json
 
-from jsonview.decorators import json_view
+from auth_pack.decorators import json_view
 from django.conf import settings
 from django.utils.http import is_safe_url
 from django.shortcuts import resolve_url
@@ -48,7 +48,8 @@ class AjaxFormViewMixin(object):
 @csrf_protect
 @never_cache
 @json_view
-def ajax_login(request, redirect_field_name=REDIRECT_FIELD_NAME, form_class=UserAuthenticationForm):
+def ajax_login(request, redirect_field_name=REDIRECT_FIELD_NAME,
+        form_class=UserAuthenticationForm, template_name='accounts/login.html'):
     redirect_to = request.REQUEST.get(redirect_field_name, '')
 
     if request.method == "POST":
@@ -69,6 +70,9 @@ def ajax_login(request, redirect_field_name=REDIRECT_FIELD_NAME, form_class=User
         else:
             form_html = render_crispy_form(form)
             return {'success': False, 'form_html': form_html}
+    elif request.method == 'GET':
+        return render_to_response(template_name, {'form': form_class(request)},
+            context_instance=RequestContext(request))
 
 
 @csrf_protect
